#!/bin/sh 

# Ce script à été conçu sur un portable Toshiba SM30X-143 avec la distribution Ubuntu 6.06 LTS ainsi que le shell bash (régler la largeur du shell à 80 caractères pour un meilleur rendu).
# A noter, sur ubuntu, notre script doit être éxecuté en mode root pour que les redirection d'erreurs marchent (comme par exemple avec le "iwlist scanning" pour avoir des infos sur les réseaux wifi).
# Les tentatives d'améliorations graphiques ont été faites d'après différents doccuments sur le shell et les couleurs dont: http://www.linuxfocus.org/Francais/May2004/article335.shtml

############################
VERT="\\033[7;32m"         #
NORMAL="\\033[0;39m"       #
ROUGE="\\033[7;31m"        # Variables permettant de colorer le shell
BLEU="\\033[7;34m"         #
BLEUFONCE="\\033[1;37;44m" #
JAUNE="\\033[7;33m"        #
CYAN="\\033[30;46m"        #
############################

#######################################   Autres variables:

# Nombre de lignes du script

NBRLINE=`cat $0 | wc -l`

# Informations relatives à la date

DATE=`date | cut -d "," -f 1`
HOUR=`date | sed 's/^\(.*\), \([0-2][0-9]\):\([0-5][0-9]\):\([0-5][0-9]\) \(.*\)$/\2 heures \3 minutes et \4 secondes/'`
SINCE=`uptime | tr -s " " | cut -d "," -f 1 | sed -e 's/^\(.*\) up \(.*\)$/\2/'`

# Informations relatives au kernel et au shellecho -e $BLEUFONCE"                                                                                "

VERSIONSHELL=`sh --version | cut -d "," -f 2 | head -n 1 | cut -d "(" -f 1 | cut -d " " -f 3`
VERSIONMAN=`man --version | cut -d " " -f 3 | cut -d "," -f 1`
DATEMAN=`man --version | cut -d " " -f 4 | sed -e 's/^\(.*\)-\(.*\)-\(.*\)$/\3-\2-\1/'`
BASHLANG=`printenv | grep "LANG=" |cut -d "=" -f 2`
VERSIONLINUX=`cat /proc/version | awk {'print $3'} | cut -d "-" -f 1`

# Informations relatives à l'utilisateur courant

YOURIP=`ifconfig | grep 'inet adr:' | tr -s " " | head -n 1 | sed -e 's/^[^:]*:\([^ ]*\).*/\1/'`
USER=`whoami`
YOURUID=`id | sed -e 's/^[^=]*=\([^\( ]*\).*/\1/'`
YOURGID=`id | sed -e 's/^[^=]*=\([^\( ]*\).* [^=]*=\([^\( ]*\).* [^=]*=\([^\( ]*\).*/\2/'`
YOURGROUPS=`groups`

# Informations relatives à un ordinateur (portable de préférence)

ARCHITECTURE=`uname --machine`
BATTERYTYPE=`cat /proc/acpi/battery/BAT1/* | grep "battery type:" | tr -s " " | cut -d " " -f 3`
AUTONOMY=`acpi | cut -d ":" -f 2 | cut -d " " -f 3`

# Informations relatives au processeur

MODELE=`cat /proc/cpuinfo | grep "model name" | tr -s " " | cut -d ":" -f 2 | sed -e 's/^\([^1-9]*\) processor \(.*\)$/\1 cadencé à \2/'`
CACHE=`cat /proc/cpuinfo | grep "size" | tr -s " " | cut -d ":" -f 2`
LOADINSTANT=`cat /proc/loadavg | cut -d " " -f 1`
LOADINSTANTP=`echo "scale=10 ; $LOADINSTANT*100" | bc -l `
LOADAVERAGE=`cat /proc/loadavg | cut -d " " -f 2`
LOADAVERAGEP=`echo "scale=10 ; $LOADAVERAGE*100" | bc -l `
PROCESS=`cat /proc/loadavg | cut -d " " -f 4 | cut -d "/" -f 2`

# Informations relatives à la mémoire

MEMTOTAL=`free | grep 'Mem' | tr -s " " | awk {'print $2'}`
MEMUSED=`free | grep 'Mem' | tr -s " " | awk {'print $3'}`
MEMUSEDP=`echo "scale=2 ; $MEMUSED/$MEMTOTAL*100" | bc -l` 
MEMFREE=`free | grep 'Mem' | tr -s " " | awk {'print $4'}`

# Informations relatives au SWAP

SWAPTOTAL=`free | grep 'Swap' | tr -s " " | awk {'print $2'}`
SWAPUSED=`free | grep 'Swap' | tr -s " " | awk {'print $3'}`
SWAPFREE=`free | grep 'Swap' | tr -s " " | awk {'print $4'}`

# Informations relatives aux disques durs

NUMBERHD=`df | grep "/dev/hda" | wc -l`

# Informations relatives aux connecteurs USB/Firewire

USB=`lspci | grep "USB".*"#" | wc -l`
FIREWIRE=`lspci | grep "FireWire" | wc -l`

# Informations relatives à la carte graphique

BRAND3D=`lspci | grep "VGA compatible" | sed -e 's/^.*: \(.*\)$/\1/'| cut -d " " -f 1`
CARDTYPE3D=`lspci | grep "VGA compatible" | sed -e 's/^.*: \(.*\)$/\1/'| cut -d "[" -f 2 | cut -d "]" -f 1`

# Informations relatives à l'environnement réseaux
LOCALHOSTNAME=`uname --nodename`
NBRWIFI=`iwlist scanning 2>/dev/null | grep "Cell" | wc -l`
NBRADHOC=`iwlist scanning 2>/dev/null | grep "Ad-Hoc" | wc -l`
NBRMASTER=`iwlist scanning 2>/dev/null | grep "Master" | wc -l`
WIFINAME=`iwlist scanning 2>/dev/null | grep "ESSID"|tr -s " " | cut -d ":" -f 2 | sed -e 's/^\"\(.*\)\"/\1/'`
WIFIINFO=`iwlist scanning 2>/dev/null | grep "ESSID"|tr -s " " | cut -d ":" -f 2 | sed -e 's/^\"\(.*\)\"/\1/'`
WIFIMOD=`iwlist scanning 2>/dev/null | grep "Mode" | tr -s " " | cut -d ":" -f 2`

# Un peut de légèreté (bien évidemment hors-sujet)
QUOTE=`fortune`

# Affichage d'un titre (de notre création) en couleur (on perd beaucoup au niveau de la lisibilité du code...)
# Le $COULEUR utilise les variables couleurs préalablement définies, elles sont de la forme: 
# séquence d'échappement "\033" puis style de caractères "[0" puis code couleur ";37" et enfin code fond ";44m".
# Le $NORMAL rétablit les valeurs par défault.
clear
echo -e $NORMAL""$ROUGE"                                                                                "
echo -e $ROUGE"                                                                                "
echo -e $ROUGE"           @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@           "
echo -e $ROUGE"           @@                                                      @@           "
echo -e $ROUGE"           @@  "$BLEU"|"$VERT"SSSSS"$BLEU"|  |"$VERT"CCCCC"$BLEU"|  |"$VERT"RRRR"$BLEU"|   |"$VERT"III"$BLEU"|  |"$VERT"PPPPP"$BLEU"|  |"$VERT"TTTTT"$BLEU"|"$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"|"$VERT"S"$BLEU"|      |"$VERT"C"$BLEU"|      |"$VERT"R"$BLEU"| |"$VERT"R"$BLEU"|   |"$VERT"I"$BLEU"|   |"$VERT"P"$BLEU"| |"$VERT"P"$BLEU"|    |"$VERT"T"$BLEU"|  "$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"|"$VERT"SSSSS"$BLEU"|  |"$VERT"C"$BLEU"|      |"$VERT"RRRR"$BLEU"|    |"$VERT"I"$BLEU"|   |"$VERT"PPPPP"$BLEU"|    |"$VERT"T"$BLEU"|  "$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"    |"$VERT"S"$BLEU"|  |"$VERT"C"$BLEU"|      |"$VERT"R"$BLEU"| |"$VERT"R"$BLEU"|   |"$VERT"I"$BLEU"|   |"$VERT"P"$BLEU"|        |"$VERT"T"$BLEU"|  "$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"|"$VERT"SSSSS"$BLEU"|  |"$VERT"CCCCC"$BLEU"|  |"$VERT"R"$BLEU"|  |"$VERT"R"$BLEU"| |"$VERT"III"$BLEU"|  |"$VERT"P"$BLEU"|        |"$VERT"T"$BLEU"|  "$ROUGE"  @@           "
echo -e $ROUGE"           @@                                                      @@           "
echo -e $ROUGE"           @@  "$BLEU"    |"$VERT"SSSSS"$BLEU"|  |"$VERT"H"$BLEU"| |"$VERT"H"$BLEU"|  |"$VERT"EEEEE"$BLEU"|  |"$VERT"L"$BLEU"|      |"$VERT"L"$BLEU"|       "$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"    |"$VERT"S"$BLEU"|      |"$VERT"H"$BLEU"| |"$VERT"H"$BLEU"|  |"$VERT"E"$BLEU"|      |"$VERT"L"$BLEU"|      |"$VERT"L"$BLEU"|       "$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"    |"$VERT"SSSSS"$BLEU"|  |"$VERT"HHHHH"$BLEU"|  |"$VERT"EEE"$BLEU"|    |"$VERT"L"$BLEU"|      |"$VERT"L"$BLEU"|       "$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"        |"$VERT"S"$BLEU"|  |"$VERT"H"$BLEU"| |"$VERT"H"$BLEU"|  |"$VERT"E"$BLEU"|      |"$VERT"L"$BLEU"|      |"$VERT"L"$BLEU"|       "$ROUGE"  @@           "
echo -e $ROUGE"           @@  "$BLEU"    |"$VERT"SSSSS"$BLEU"|  |"$VERT"H"$BLEU"| |"$VERT"H"$BLEU"|  |"$VERT"EEEEE"$BLEU"|  |"$VERT"LLLLL"$BLEU"|  |"$VERT"LLLLL"$BLEU"|   "$ROUGE"  @@           "
echo -e $ROUGE"           @@                                                      @@           "
echo -e $ROUGE"           @@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@           "$NORMAL""

echo -e $ROUGE"                                                                                "
echo -e $ROUGE"             Vous allez bientôt voir nos "$NBRLINE" lignes de code s'exprimer.           "
echo -e $ROUGE"                                                                                "
echo -e $ROUGE"                    (Appuyer sur une touche pour continuer)                     "
echo -e $ROUGE"                                                                                "$NORMAL""; read ;

choix=0

while (true);do
clear
echo -e $JAUNE"                                                                                "
echo -e $JAUNE" "$CYAN"                                                                              "$JAUNE" "
echo -e $JAUNE" "$CYAN"                         "$VERT"MM"$CYAN"   "$VERT"MM"$CYAN"  "$VERT"EEEEE"$CYAN"   "$VERT"NN"$CYAN"    "$VERT"N"$CYAN"  "$VERT"U"$CYAN"     "$VERT"U"$CYAN"                    "$JAUNE" "
echo -e $JAUNE" "$CYAN"                         "$VERT"M"$CYAN" "$VERT"M"$CYAN" "$VERT"M"$CYAN" "$VERT"M"$CYAN"  "$VERT"E"$CYAN"       "$VERT"N"$CYAN" "$VERT"N"$CYAN"   "$VERT"N"$CYAN"  "$VERT"U"$CYAN"     "$VERT"U"$CYAN"                    "$JAUNE" "
echo -e $JAUNE" "$CYAN"                         "$VERT"M"$CYAN"  "$VERT"M"$CYAN"  "$VERT"M"$CYAN"  "$VERT"EEE"$CYAN"     "$VERT"N"$CYAN"  "$VERT"N"$CYAN"  "$VERT"N"$CYAN"  "$VERT"U"$CYAN"     "$VERT"U"$CYAN"                    "$JAUNE" "
echo -e $JAUNE" "$CYAN"                         "$VERT"M"$CYAN"  "$VERT"M"$CYAN"  "$VERT"M"$CYAN"  "$VERT"E"$CYAN"       "$VERT"N"$CYAN"   "$VERT"N"$CYAN" "$VERT"N"$CYAN"   "$VERT"U"$CYAN"   "$VERT"U"$CYAN"                     "$JAUNE" "
echo -e $JAUNE" "$CYAN"                         "$VERT"M"$CYAN"     "$VERT"M"$CYAN"  "$VERT"EEEEE"$CYAN"   "$VERT"N"$CYAN"    "$VERT"NN"$CYAN"    "$VERT"UUU"$CYAN"                      "$JAUNE" "
echo -e $JAUNE" "$CYAN"                                                                              "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives à la date.....................1          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives au kernel et au shell.........2          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives à l'utilisateur courant.......3          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives à un ordinateur portable......4          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives au processeur.................5          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives à la mémoire..................6          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives aux disques durs..............7          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives aux connecteurs USB/Firewire..8          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives à la carte graphique..........9          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Informations relatives à l'environnement réseaux.....a          "$JAUNE" "
echo -e $JAUNE" "$CYAN"              Un peu de hors sujet.................................b          "$JAUNE" " 
echo -e $JAUNE" "$CYAN"              Quitter..............................................C          "$JAUNE" "
echo -e $JAUNE" "$CYAN"                                                                              "$JAUNE" "
echo -e $JAUNE"                                                                                "$NORMAL""
read choix
case $choix in

'1') clear
echo -e $CYAN"                                                                                "
echo -e $CYAN"Informations relatives à la date................................................"
echo -e $CYAN"                                                                                "
echo -e $CYAN"   Bienvenue, nous sommes le "$DATE".                            "
echo -e $CYAN"   Il est "$HOUR".                                  "
echo -e $CYAN"   Votre ordinateur est allumé depuis "$SINCE".                                     "
echo -e $CYAN"                                                                                "
echo -e $CYAN"   (Appuyer sur une entrer pour retourner au menu.)                             "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "$NORMAL""; read ;

;;

'2') clear
echo -e $CYAN"                                                                                "
echo -e $CYAN"Informations relatives au kernel et au shell...................................."
echo -e $CYAN"                                                                                "
echo -e $CYAN"   Vous utilisez la version "$VERSIONSHELL" du shell bash.                               "
echo -e $CYAN"   Votre shell est configuré dans le language et le format : "$BASHLANG" .      "
echo -e $CYAN"   Votre shell dispose de la version "$VERSIONMAN" du manuel datée du "$DATEMAN".       "
echo -e $CYAN"   Vous utilisez la version "$VERSIONLINUX" du noyau Linux.                              "
echo -e $CYAN"                                                                                "
echo -e $CYAN"   (Appuyer sur une entrer pour retourner au menu.)                             "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "$NORMAL""; read ;
;;

'3') clear
echo -e $CYAN"                                                                                "
echo -e $CYAN"Informations relatives à l'utilisateur courant.................................."
echo -e $CYAN"                                                                                "
echo -e $CYAN"Votre IP est : "$YOURIP".                                                       "
echo -e $CYAN"Vous êtes l'utilisateur "$USER".                                                   "
echo -e $CYAN"Votre UID est "$YOURUID".                                                                "
echo -e $CYAN"Votre GID "$YOURGID".                                                                    "
echo -e $CYAN"Vous appartenez aux groupes : "$YOURGROUPS".                                             "
echo -e $CYAN"                                                                                "
echo -e $CYAN"   (Appuyer sur une entrer pour retourner au menu.)                             "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "$NORMAL""; read ;
;;

'4') clear 
echo -e $CYAN"                                                                                "
echo -e $CYAN"Informations relatives à l'ordinateur (portable de préférence).................."
echo -e $CYAN"                                                                                "
echo -e $CYAN"Votres machine à une architecture du type: "$ARCHITECTURE".                                "
echo -e $CYAN"Votre batterie est chargée à "$AUTONOMY".                                              "
echo -e $CYAN"Votre batterie fonctionne au "$BATTERYTYPE".                                            "
echo -e $CYAN"                                                                                "
echo -e $CYAN"   (Appuyer sur une entrer pour retourner au menu.)                             "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "$NORMAL""; read ;
;;

'5') clear
echo -e $CYAN"                                                                                "
echo -e $CYAN"Informations relatives au processeur............................................"
echo -e $CYAN"                                                                                "
echo -e $CYAN"Modèle : "$MODELE".                              "
echo -e $CYAN"Taille du cache : "$CACHE".                                                     "
echo -e $CYAN"Charge actuelle du processeur : "$LOADINSTANTP"%.                                         "
echo -e $CYAN"Charge moyenne sur 5 minutes : "$LOADAVERAGEP"%.                                          "
echo -e $CYAN"Vous avez actuellement "$PROCESSUS" processus de lancés sur votre système.                  "
echo -e $CYAN"                                                                                "
echo -e $CYAN"   (Appuyer sur une entrer pour retourner au menu.)                             "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "$NORMAL""; read ;

;;

'6') clear
echo -e $CYAN"                                                                                "
echo -e $CYAN"Informations relatives à la mémoire............................................."
echo -e $CYAN"                                                                                "
echo -e $CYAN"Mémoire totale : "$MEMTOTAL" Ko.                                                     "
echo -e $CYAN"Mémoire utilisée : "$MEMUSED" Ko.                                                   "
echo -e $CYAN"Mémoire libre : "$MEMFREE" Ko.                                                      "
echo -e $CYAN"Soit "$MEMUSEDP"% de mémoire utilisée.                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"Taille totale du swap : "$SWAPTOTAL" Ko.                                             "
echo -e $CYAN"Swap utilisé : "$SWAPUSED" Ko.                                                        "
echo -e $CYAN"Swap libre : "$SWAPFREE" Ko.                                                        "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"   (Appuyer sur une entrer pour retourner au menu.)                             "
echo -e $CYAN"                                                                                "$NORMAL""; read ;
;;

'7') clear
echo "                                                                                "
echo "Informations relatives aux disques durs........................................."
echo "                                                                                "
echo "Vous avez "$NUMBERHD" disques séparés (physiquement où virtuelement).                     "
echo "                                                                                "
df -h | grep "Sys.";df -h | grep "/dev/hda" 
#Ici pas de passage par une variable pour éviter un redimensionnement du tableau en colonne.
echo "                                                                                "
echo "   (Appuyer sur une entrer pour retourner au menu.)                             "
echo "                                                                                "; read ;
;;

'8') clear
echo "                                                                                "
echo "Informations relatives aux connecteurs USB/Firewire............................."
echo "                                                                                "
echo "Vous avez "$USB" ports USB.                                                              "
echo "Vous avez "$FIREWIRE" connecteur FireWire.                                                  "
echo "                                                                                "
echo "   (Appuyer sur une entrer pour retourner au menu.)                             "
echo "                                                                                "; read ;
;;

'9') clear
echo "                                                                                "
echo "Informations relatives à la carte graphique....................................."
echo "                                                                                "
echo "Votre carte graphique provient du constructeur "$BRAND3D".                            "
echo "Son modèle est le suivant :"$CARDTYPE3D".                       "
echo "                                                                                "
echo "                                                                                "
echo "                                                                                "
echo "                                                                                "
echo "   (Appuyer sur une entrer pour retourner au menu.)                             "
echo "                                                                                "$NORMAL""; read ;
;;

'a') clear
echo "                                                                                "
echo "Informations relatives à l'environnement réseaux sans fils......................"
echo "                                                                                "
echo "Votre réseaux local porte le nom: "$LOCALHOSTNAME" .                               "
echo "Il existe "$NBRWIFI" réseaux wifi à votre portée dont:                                    "
echo "   - "$NBRADHOC" en mode Ad-Hoc                                                             "
echo "   - "$NBRMASTER" en  mode Master                                                             "
echo "Ces réseaux portent les noms:                                                   "
echo ""$WIFINAME"                                                        "
echo "Et leurs modes respectifs sont:                                                 "
echo ""$WIFIMOD"                                                         "
echo "                                                                                "
echo "                                                                                "
echo "                                                                                "
echo "   (Appuyer sur une entrer pour retourner au menu.)                             "
echo "                                                                                "; read ;
;;

'b') clear
echo "                                                                                "
echo "Un peu de hors sujet............................................................"
echo "                                                                                "
echo "Peut-être une petite citation, où alors une prédiction sinon un conseil:        "
echo "(Dans la langue de Shakespear bien évidemment)                                  "
echo ""$QUOTE"                                                                                "
echo "                                                                                "
echo "   (Appuyer sur une entrer pour retourner au menu.)                             "
echo "                                                                                "
echo "                                                                                "
echo "                                                                                "
echo "                                                                                "; read ;
;;

'c') clear
echo -e $CYAN"                                                                                "
echo -e $CYAN"Fermeture......................................................................."
echo -e $CYAN"                                                                                "
echo -e $CYAN"   (Appuyer sur une entrer pour retourner au shell.)                            "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "
echo -e $CYAN"                                                                                "$NORMAL""; read ;
exit 0
;;                                                                                

*) clear
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"   Erreur de saisie !                                                           "
echo -e $BLEUFONCE"   Le programme ayant subit une opération non conforme, il va quitter.          "
echo -e $BLEUFONCE"   Veuillez enregistrer votre travail puis appuyer sur entrer.                  "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "
echo -e $BLEUFONCE"                                                                                "$NORMAL"";read;

exit 1 #Quitte en renvoyant un code d'erreur
;;

esac
done
